SyncMetrics class

Metrics for monitoring syncitron's sync performance.

Constructors

SyncMetrics({required String tableName, DateTime? startTime})

Properties

conflictsResolved int
getter/setter pair
duration Duration
no setter
endTime DateTime
getter/setter pair
errorMessages List<String>
getter/setter pair
errors int
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
recordsPulled int
getter/setter pair
recordsPushed int
getter/setter pair
recordsWithConflicts int
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
startTime DateTime
final
success bool
no setter
tableName String
final
totalRecordsProcessed int
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
recordError(String message) → void
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited